==> packages-19.1.4-LibreSSL-amd64.tar: usr/local/opnsense/mvc/app/controllers/OPNsense/Siproxd/Api/DomainController.php <==
<?php
/**
 *    Copyright (C) 2015 - 2017 Deciso B.V.
 *    Copyright (C) 2017 Michael Muenz <m.muenz@gmail.com>
 *
 *    All rights reserved.
 *
 *    Redistribution and use in source and binary forms, with or without
 *    modification, are permitted provided that the following conditions are met:
 *
 *    1. Redistributions of source code must retain the above copyright notice,
 *       this list of conditions and the following disclaimer.
 *
 *    2. Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *
 *    THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
 *    INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 *    AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *    AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 *    OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 *    SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 *    INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 *    CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 *    ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *    POSSIBILITY OF SUCH DAMAGE.
 *
 */

namespace OPNsense\Siproxd\Api;

use \OPNsense\Siproxd\Domain;
use \OPNsense\Core\Config;
use \OPNsense\Base\ApiMutableModelControllerBase;
use \OPNsense\Base\UIModelGrid;

class DomainController extends ApiMutableModelControllerBase
{
    protected static $internalModelName = 'Domain';
    protected static $internalModelClass = '\OPNsense\Siproxd\Domain';

    public function getAction()
    {
        // define list of configurable settings
        $result = array();
        if ($this->request->isGet()) {
            $mdlDomain = new Domain();
            $result['domain'] = $mdlDomain->getNodes();
        }
        return $result;
    }

    public function setAction()
    {
        $result = array("result"=>"failed");
        if ($this->request->isPost()) {
            // load model and update with provided data
            $mdlDomain = new Domain();
            $mdlDomain->setNodes($this->request->getPost("domain"));
            // perform validation
            $valMsgs = $mdlDomain->performValidation();
            foreach ($valMsgs as $field => $msg) {
                if (!array_key_exists("validations", $result)) {
                    $result["validations"] = array();
                }
                $result["validations"]["domain.".$msg->getField()] = $msg->getMessage();
            }
            // serialize model to config and save
            if ($valMsgs->count() == 0) {
                $mdlDomain->serializeToConfig();
                Config::getInstance()->save();
                $result["result"] = "saved";
            }
        }
        return $result;
    }

    public function searchDomainAction()
    {
        $this->sessionClose();
        $mdlDomain = $this->getModel();
        $grid = new UIModelGrid($mdlDomain->domains->domain);
        return $grid->fetchBindRequest(
            $this->request,
            array("enabled", "name", "host", "port" )
        );
    }

    public function getDomainAction($uuid = null)
    {
        $mdlDomain = $this->getModel();
        if ($uuid != null) {
            $node = $mdlDomain->getNodeByReference('domains.domain.' . $uuid);
            if ($node != null) {
                // return node
                return array("domain" => $node->getNodes());
            }
        } else {
            $node = $mdlDomain->domains->domain->add();
            return array("domain" => $node->getNodes());
        }
        return array();
    }

    public function addDomainAction()
    {
        $result = array("result" => "failed");
        if ($this->request->isPost() && $this->request->hasPost("domain")) {
            $result = array("result" => "failed", "validations" => array());
            $mdlDomain = $this->getModel();
            $node = $mdlDomain->domains->domain->Add();
            $node->setNodes($this->request->getPost("domain"));
            $valMsgs = $mdlDomain->performValidation();
            foreach ($valMsgs as $field => $msg) {
                $fieldnm = str_replace($node->__reference, "domain", $msg->getField());
                $result["validations"][$fieldnm] = $msg->getMessage();
            }
            if (count($result['validations']) == 0) {
                unset($result['validations']);
                // save config if validated correctly
                $mdlDomain->serializeToConfig();
                Config::getInstance()->save();
                unset($result['validations']);
                $result["result"] = "saved";
            }
        }
        return $result;
    }

    public function delDomainAction($uuid)
    {
        $result = array("result" => "failed");
        if ($this->request->isPost()) {
            $mdlDomain = $this->getModel();
            if ($uuid != null) {
                if ($mdlDomain->domains->domain->del($uuid)) {
                    $mdlDomain->serializeToConfig();
                    Config::getInstance()->save();
                    $result['result'] = 'deleted';
                } else {
                    $result['result'] = 'not found';
                }
            }
        }
        return $result;
    }

    public function setDomainAction($uuid)
    {
        if ($this->request->isPost() && $this->request->hasPost("domain")) {
            $mdlSetting = $this->getModel();
            if ($uuid != null) {
                $node = $mdlSetting->getNodeByReference('domains.domain.' . $uuid);
                if ($node != null) {
                    $result = array("result" => "failed", "validations" => array());
                    $domainInfo = $this->request->getPost("domain");
                    $node->setNodes($domainInfo);
                    $valMsgs = $mdlSetting->performValidation();
                    foreach ($valMsgs as $field => $msg) {
                        $fieldnm = str_replace($node->__reference, "domain", $msg->getField());
                        $result["validations"][$fieldnm] = $msg->getMessage();
                    }
                    if (count($result['validations']) == 0) {
                        // save config if validated correctly
                        $mdlSetting->serializeToConfig();
                        Config::getInstance()->save();
                        $result = array("result" => "saved");
                    }
                    return $result;
                }
            }
        }
        return array("result" => "failed");
    }

    public function toggle_handler($uuid, $elements, $element)
    {
        $result = array("result" => "failed");
        if ($this->request->isPost()) {
            $mdlSetting = $this->getModel();
            if ($uuid != null) {
                $node = $mdlSetting->getNodeByReference($elements . '.'. $element .'.' . $uuid);
                if ($node != null) {
                    if ($node->enabled->__toString() == "1") {
                        $result['result'] = "Disabled";
                        $node->enabled = "0";
                    } else {
                        $result['result'] = "Enabled";
                        $node->enabled = "1";
                    }
                    // if item has toggled, serialize to config and save
                    $mdlSetting->serializeToConfig();
                    Config::getInstance()->save();
                }
            }
        }
        return $result;
    }

    public function toggleDomainAction($uuid)
    {
        return $this->toggle_handler($uuid, 'domains', 'domain');
    }
}

==> packages-20.7-LibreSSL-amd64.tar: usr/local/opnsense/mvc/app/controllers/OPNsense/Siproxd/Api/DomainController.php <==
<?php

/**
 *    Copyright (C) 2015 - 2017 Deciso B.V.
 *    Copyright (C) 2017 Michael Muenz <m.muenz@gmail.com>
 *
 *    All rights reserved.
 *
 *    Redistribution and use in source and binary forms, with or without
 *    modification, are permitted provided that the following conditions are met:
 *
 *    1. Redistributions of source code must retain the above copyright notice,
 *       this list of conditions and the following disclaimer.
 *
 *    2. Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *
 *    THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
 *    INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 *    AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *    AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 *    OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 *    SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 *    INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 *    CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 *    ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *    POSSIBILITY OF SUCH DAMAGE.
 *
 */

namespace OPNsense\Siproxd\Api;

use OPNsense\Siproxd\Domain;
use OPNsense\Core\Config;
use OPNsense\Base\ApiMutableModelControllerBase;
use OPNsense\Base\UIModelGrid;

class DomainController extends ApiMutableModelControllerBase
{
    protected static $internalModelName = 'Domain';
    protected static $internalModelClass = '\OPNsense\Siproxd\Domain';

    public function getAction()
    {
        // define list of configurable settings
        $result = array();
        if ($this->request->isGet()) {
            $mdlDomain = new Domain();
            $result['domain'] = $mdlDomain->getNodes();
        }
        return $result;
    }

    public function setAction()
    {
        $result = array("result" => "failed");
        if ($this->request->isPost()) {
            // load model and update with provided data
            $mdlDomain = new Domain();
            $mdlDomain->setNodes($this->request->getPost("domain"));
            // perform validation
            $valMsgs = $mdlDomain->performValidation();
            foreach ($valMsgs as $field => $msg) {
                if (!array_key_exists("validations", $result)) {
                    $result["validations"] = array();
                }
                $result["validations"]["domain." . $msg->getField()] = $msg->getMessage();
            }
            // serialize model to config and save
            if ($valMsgs->count() == 0) {
                $mdlDomain->serializeToConfig();
                Config::getInstance()->save();
                $result["result"] = "saved";
            }
        }
        return $result;
    }

    public function searchDomainAction()
    {
        $this->sessionClose();
        $mdlDomain = $this->getModel();
        $grid = new UIModelGrid($mdlDomain->domains->domain);
        return $grid->fetchBindRequest(
            $this->request,
            array("enabled", "name", "host", "port" )
        );
    }

    public function getDomainAction($uuid = null)
    {
        $mdlDomain = $this->getModel();
        if ($uuid != null) {
            $node = $mdlDomain->getNodeByReference('domains.domain.' . $uuid);
            if ($node != null) {
                // return node
                return array("domain" => $node->getNodes());
            }
        } else {
            $node = $mdlDomain->domains->domain->add();
            return array("domain" => $node->getNodes());
        }
        return array();
    }

    public function addDomainAction()
    {
        $result = array("result" => "failed");
        if ($this->request->isPost() && $this->request->hasPost("domain")) {
            $result = array("result" => "failed", "validations" => array());
            $mdlDomain = $this->getModel();
            $node = $mdlDomain->domains->domain->Add();
            $node->setNodes($this->request->getPost("domain"));
            $valMsgs = $mdlDomain->performValidation();
            foreach ($valMsgs as $field => $msg) {
                $fieldnm = str_replace($node->__reference, "domain", $msg->getField());
                $result["validations"][$fieldnm] = $msg->getMessage();
            }
            if (count($result['validations']) == 0) {
                unset($result['validations']);
                // save config if validated correctly
                $mdlDomain->serializeToConfig();
                Config::getInstance()->save();
                unset($result['validations']);
                $result["result"] = "saved";
            }
        }
        return $result;
    }

    public function delDomainAction($uuid)
    {
        $result = array("result" => "failed");
        if ($this->request->isPost()) {
            $mdlDomain = $this->getModel();
            if ($uuid != null) {
                if ($mdlDomain->domains->domain->del($uuid)) {
                    $mdlDomain->serializeToConfig();
                    Config::getInstance()->save();
                    $result['result'] = 'deleted';
                } else {
                    $result['result'] = 'not found';
                }
            }
        }
        return $result;
    }

    public function setDomainAction($uuid)
    {
        if ($this->request->isPost() && $this->request->hasPost("domain")) {
            $mdlSetting = $this->getModel();
            if ($uuid != null) {
                $node = $mdlSetting->getNodeByReference('domains.domain.' . $uuid);
                if ($node != null) {
                    $result = array("result" => "failed", "validations" => array());
                    $domainInfo = $this->request->getPost("domain");
                    $node->setNodes($domainInfo);
                    $valMsgs = $mdlSetting->performValidation();
                    foreach ($valMsgs as $field => $msg) {
                        $fieldnm = str_replace($node->__reference, "domain", $msg->getField());
                        $result["validations"][$fieldnm] = $msg->getMessage();
                    }
                    if (count($result['validations']) == 0) {
                        // save config if validated correctly
                        $mdlSetting->serializeToConfig();
                        Config::getInstance()->save();
                        $result = array("result" => "saved");
                    }
                    return $result;
                }
            }
        }
        return array("result" => "failed");
    }

    public function toggle_handler($uuid, $elements, $element)
    {
        $result = array("result" => "failed");
        if ($this->request->isPost()) {
            $mdlSetting = $this->getModel();
            if ($uuid != null) {
                $node = $mdlSetting->getNodeByReference($elements . '.' . $element . '.' . $uuid);
                if ($node != null) {
                    if ($node->enabled->__toString() == "1") {
                        $result['result'] = "Disabled";
                        $node->enabled = "0";
                    } else {
                        $result['result'] = "Enabled";
                        $node->enabled = "1";
                    }
                    // if item has toggled, serialize to config and save
                    $mdlSetting->serializeToConfig();
                    Config::getInstance()->save();
                }
            }
        }
        return $result;
    }

    public function toggleDomainAction($uuid)
    {
        return $this->toggle_handler($uuid, 'domains', 'domain');
    }
}
